utils

package
v0.0.1-0...-4a2c530 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package utils contains methods to validate user input for cluster operations.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ValidateClusterName

func ValidateClusterName(name string) error

ValidateClusterName accepts a cluster name and returns an error if it does not comply with the requirements.

func ValidateLifespan

func ValidateLifespan(lifespan time.Duration) error

ValidateLifespan accepts a duration and returns an error if it does not comply with the requirements.

func ValidateParameterArgument

func ValidateParameterArgument(parts []string) error

ValidateParameterArgument checks that key-value parameter arguments comply with the requirements.

Types

This section is empty.

Jump to