service

package
v0.0.1-0...-4a2c530 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2025 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Overview

Package service implements the backend services for the infra server.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCliService

func NewCliService(staticDir string) (middleware.APIService, error)

NewCliService creates a new CliUpgradeService.

func NewFlavorService

func NewFlavorService(registry *flavor.Registry) (middleware.APIService, error)

NewFlavorService creates a new FlavorService.

func NewStatusService

func NewStatusService() (middleware.APIService, error)

NewStatusService creates a new InfraStatusService.

func NewUserService

func NewUserService(generator func(*v1.ServiceAccount) (string, error)) (middleware.APIService, error)

NewUserService creates a new UserService.

func NewVersionService

func NewVersionService() (middleware.APIService, error)

NewVersionService creates a new VersionService.

Types

This section is empty.

Directories

Path Synopsis
Package cluster provides an implementation for the Cluster gRPC service.
Package cluster provides an implementation for the Cluster gRPC service.
Package metrics exposes custom metrics for the infra server.
Package metrics exposes custom metrics for the infra server.
Package middleware provides functionality for instrumenting and enriching grpc connections.
Package middleware provides functionality for instrumenting and enriching grpc connections.

Jump to